# Changelog

All notable changes to this project will be documented in this file.

## [0.4.3] - 2025-12-03

### 🚀 Features

- Publish builds to PyPi via GH workflows

## [0.4.2] - 2025-12-03

### 🚀 Features

- Add test coverage, benchmarking, auto changelog
- Add docs through mkDocs

### 🐛 Bug Fixes

- Fix IDE imports
- Removing spurious hello.py

### 🧪 Testing

- Test type checking and parametrize tests

<!-- generated by git-cliff -->
